/*
	This source code is property of e dot studios. Any modifications or use of this code in other applications or derived works, in parts or in whole, is prohibited without the specific permission of the author. 
	e dot studios cannot be held responsible for any damage that may be caused by the use or misuse of this product.
	
	For more information contact e dot studios (contact@edot-studios.com)
*/

var gMyScrollArea, gMyScrollbar;
var gFeedBaseURL = "http://www.apple.com/trailers/home/feeds/";
var gSelectedMovie = null;
var gMoviesList = [];
var gLoaderDiv = null;
var gUpdateTimer = null;
var gLastUpdate = null;

function init() {
	if (window.widget) {
		widget.onshow = onshow;
  		widget.onhide = onhide;
  		widget.onremove = onremove;
  		
  		gInfoButton = new AppleInfoButton(document.getElementById("infoButton"), document.getElementById("front"), "white", "white", showBack);
  		gDoneButton = new AppleGlassButton(document.getElementById("doneButton"), "Done", hideBack);

		gMyScrollbar = new AppleVerticalScrollbar(document.getElementById("movies_list_sbar"));
	    gMyScrollArea = new AppleScrollArea(document.getElementById("movies_list"));
	    gMyScrollArea.addScrollbar(gMyScrollbar);
		
		gLoaderDiv = $('loader');
		gLoaderDiv.hide();
		
		//didSelectCategory();
		onshow();
	}
}

function onshow() {
	startUpdates();
}

function onhide() {
	stopUpdates();
}

function onremove() {
	onhide();
}

function startUpdates() {
	stopUpdates();
	
	shouldUpdate();
	
	gUpdateTimer = setInterval(shouldUpdate.bind(this), 60000);
}

function stopUpdates() {
	if (gUpdateTimer) {
		clearInterval(gUpdateTimer);
	}
}

function shouldUpdate() {
	var now = new Date().getTime();
	
	if (gLastUpdate == null) gLastUpdate = now;
	
	var delta = parseInt(now-gLastUpdate);
	if (delta == 0 || delta >= 1000*60*60) {
		didSelectCategory();
		gLastUpdate = now;
	}
}

/* Backside */

function showBack() {
	var front = document.getElementById("front");
    var back = document.getElementById("back");
    
    if (window.widget)
        widget.prepareForTransition("ToBack");

    front.style.display="none";
    back.style.display="block";
	
    if (window.widget)
        setTimeout ('widget.performTransition();', 0);
}

function hideBack() {
    var front = document.getElementById("front");
    var back = document.getElementById("back");

    if (window.widget)
        widget.prepareForTransition("ToFront");

    back.style.display="none";
    front.style.display="block";
		
    if (window.widget)
 		setTimeout ('widget.performTransition();', 0); 
}

/* Functions */

function didSelectCategory() {
	var txtElement = $('categories_text');
	var element = $('categories_popup');
	
	var selectedIndex = element.selectedIndex;
	var option = element.options[selectedIndex];

	txtElement.innerHTML = option.text;
	
	Effect.Appear(gLoaderDiv, {duration: 0.5});
	
	new Ajax.Request(gFeedBaseURL+option.value, {
		method: 'get',
		requestHeaders: {Accept: 'application/json'},
		onSuccess: function(xhr) { this.BuildMoviesList(xhr.responseText.evalJSON()); }.bind(this)
	});
}

function BuildMoviesList(json) {
	var movies_list = $('movies_list');
	var movies_content = $('movies_content');
	
	var ulElement = document.createElement('ul');
	ulElement = $(ulElement);
	
	movies_list.innerHTML = "";
	movies_list.appendChild(ulElement);
	
	movies_content.innerHTML = "";
	
	while (gMoviesList.length > 0) { gMoviesList.shift(); }
	
	Effect.Fade(gLoaderDiv, {duration: 0.5});
	
	for (var i=0; i<json.length; i++) {
		var item = json[i];
		
		var liElement = document.createElement('li');
		liElement = $(liElement);

		liElement.innerHTML = item.title;
		ulElement.appendChild(liElement);
		
		Event.observe(liElement, 'click', handleMovieClick.bindAsEventListener(this, i));
		
		gMoviesList.push({object: item, element: liElement});
	}
	
	gMyScrollArea.refresh();
	
	handleMovieClick(null, 0);
}

function handleMovieClick(event, index) {
	var movieItem = gMoviesList[index];
	var movieElement = movieItem.element;
	
	if (gSelectedMovie == movieElement) return;
	
	if (gSelectedMovie != null) {
		gSelectedMovie.removeClassName('selected');
	}
	
	var movieObject = movieItem.object;
	var content = $('movies_content');
	$(content).hide();
	
	var container = document.createElement("div");
	$(container).addClassName('movie_content_container');
	
	var mPosterContainer = document.createElement('span');
	$(mPosterContainer).addClassName('movies_poster_container');
	
	var mPoster = document.createElement('img');
	mPoster.setAttribute('src', movieObject.poster);
	
	$(mPosterContainer).appendChild(mPoster);
	$(container).appendChild(mPosterContainer);
	
	var mDesc = document.createElement('div');
	$(mDesc).addClassName('movie_description');
	$(container).appendChild(mDesc);
	
	mDesc.innerHTML = this.getMovieDescription(movieObject);
	
	var mNavButtons = document.createElement('div');
	$(mNavButtons).addClassName('movie_trailers');
	$(container).appendChild(mNavButtons);
	
	if (movieObject.moviesite != undefined) {
		var mOfficialPage = document.createElement('div');
		$(mNavButtons).appendChild(mOfficialPage);
		
		new AppleGlassButton(
		    $(mOfficialPage),
		    "Official Website",
		    function() { widget.openURL(movieObject.moviesite); }
		);
	}
	
	if (movieObject.location != undefined) {
		var mPage = document.createElement('div');
		$(mNavButtons).appendChild(mPage);
		
		new AppleGlassButton(
		    $(mPage),
		    "Trailer Website",
		    function() { widget.openURL('http://www.apple.com'+movieObject.location); }
		);
	}
	
	if (movieObject.soundtrack != undefined) {
		var mOST = document.createElement('div');
		$(mNavButtons).appendChild(mOST);
		
		new AppleGlassButton(
		    $(mPage),
		    "Soundtrack",
		    function() { widget.openURL('http://phobos.apple.com/WebObjects/MZStore.woa/wa/viewAlbum?playlistId='+movieObject.soundtrack[0].link); }
		);
	}
	
	if (content.childNodes.length > 0) content.removeChild(content.firstChild);
	$('movies_content').appendChild(container);
	
	gSelectedMovie = movieElement;
	gSelectedMovie.addClassName('selected');
	
	Effect.Appear(content);
}

function getMovieDescription(item) {
	var title = item.title == undefined ? 'Unknown' : item.title
	var director = item.director == undefined ? 'Unknown' : item.director;
	var studio = item.studio == undefined ? 'Unknown' : item.studio;
	var releasedate = item.releasedate == undefined ? 'Unknown' : item.releasedate.match(/.... \d\d+ ... \d{4}/);
	var actors = item.actors == undefined ? [] : item.actors;
	
	var html = "";
	html += "<strong>Title:</strong> "+title+"<br />";
	html += "<strong>Director:</strong> "+director+"<br />";
	html += "<strong>Studio:</strong> "+studio+"<br />";
	html += "<strong>Release:</strong> "+releasedate+"<br />";
	if (actors.length > 0) {
		html += "<strong>Actors:</strong> ";
		for (var a=0; a<actors.length-1;a++) {
			html += actors[a]+", ";
		}
		html += actors[actors.length-1]+"<br />";
	}
	/*if (item.trailers.length > 0) {
		html += "<strong>Trailers:</strong> ";
		html += "<select>";
		
		for (var t=0; t<item.trailers.length;t++) {
			var trailer = item.trailers[t];
			
			html += "<option value='"+"http://www.apple.com"+trailer.url+"'>";
			html += trailer.type;
			html += "</option>";
		}
		
		html += "</select>";
		html += "watch";
	}*/
	
	return html;
}